@@ -7,12 +7,30 @@ use warnings;
 use Role::Tiny::With;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-09-28'; # DATE
+our $DATE = '2021-09-29'; # DATE
 our $DIST = 'TableDataRoles-Standard'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 with 'TableDataRole::Source::AOA';
 
+our %SPEC;
+
+$SPEC{new} = {
+    v => 1.1,
+    is_meth => 1,
+    is_func => 0,
+    args => {
+        aoa => {
+            schema => 'aoa*',
+            req => 1,
+        },
+        column_names => {
+            schema => 'aos*',
+            req => 1,
+        },
+    },
+};
+
 1;
 # ABSTRACT: Get table data from array of arrays
 
@@ -28,7 +46,7 @@ TableData::AOA - Get table data from array of arrays
 
 =head1 VERSION
 
-This document describes version 0.012 of TableData::AOA (from Perl distribution TableDataRoles-Standard), released on 2021-09-28.
+This document describes version 0.013 of TableData::AOA (from Perl distribution TableDataRoles-Standard), released on 2021-09-29.
 
 =head1 SYNOPSIS
 
@@ -44,6 +62,39 @@ This document describes version 0.012 of TableData::AOA (from Perl distribution
 This is a TableData:: module to get table data from array of arrays. You also
 need to supply column names in C<column_names>.
 
+=head1 METHODS
+
+
+=head2 new
+
+Usage:
+
+ new(%args) -> [$status_code, $reason, $payload, \%result_meta]
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<aoa>* => I<aoa>
+
+=item * B<column_names>* => I<aos>
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element ($status_code) is an integer containing HTTP-like status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
+
+Return value:  (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/TableDataRoles-Standard>.
