@@ -7,12 +7,35 @@ use warnings;
 use Role::Tiny::With;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-09-28'; # DATE
+our $DATE = '2021-09-29'; # DATE
 our $DIST = 'TableDataRoles-Standard'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 with 'TableDataRole::Munge::Filter';
 
+our %SPEC;
+
+$SPEC{new} = {
+    v => 1.1,
+    is_meth => 1,
+    is_func => 0,
+    args => {
+        tabledata => {
+            schema => 'any*', # TMP
+            req => 1,
+        },
+        filter => {
+            schema => ['any*', of=>['str*', 'code*']],
+        },
+        filter_hashref => {
+            schema => ['any*', of=>['str*', 'code*']],
+        },
+    },
+    args_rels => {
+        req_one => [qw/filter filter_hashref/],
+    },
+};
+
 1;
 # ABSTRACT: Filter rows of another tabledata
 
@@ -28,7 +51,7 @@ TableData::Munge::Filter - Filter rows of another tabledata
 
 =head1 VERSION
 
-This document describes version 0.012 of TableData::Munge::Filter (from Perl distribution TableDataRoles-Standard), released on 2021-09-28.
+This document describes version 0.013 of TableData::Munge::Filter (from Perl distribution TableDataRoles-Standard), released on 2021-09-29.
 
 =head1 SYNOPSIS
 
@@ -44,6 +67,41 @@ This document describes version 0.012 of TableData::Munge::Filter (from Perl dis
 This is a TableData:: module that lets you filter rows from another tabledata.
 See L<TableDataRole::Munge::Filter> for more details.
 
+=head1 METHODS
+
+
+=head2 new
+
+Usage:
+
+ new(%args) -> [$status_code, $reason, $payload, \%result_meta]
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<filter> => I<str|code>
+
+=item * B<filter_hashref> => I<str|code>
+
+=item * B<tabledata>* => I<any>
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element ($status_code) is an integer containing HTTP-like status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
+
+Return value:  (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/TableDataRoles-Standard>.
