@@ -3,9 +3,9 @@
 package TableData::Test::Source::AOA;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-09-28'; # DATE
+our $DATE = '2021-09-29'; # DATE
 our $DIST = 'TableDataRoles-Standard'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 use alias::module 'TableData::AOA';
 
@@ -24,7 +24,40 @@ TableData::Test::Source::AOA - Alias package for TableData::AOA
 
 =head1 VERSION
 
-This document describes version 0.012 of TableData::Test::Source::AOA (from Perl distribution TableDataRoles-Standard), released on 2021-09-28.
+This document describes version 0.013 of TableData::Test::Source::AOA (from Perl distribution TableDataRoles-Standard), released on 2021-09-29.
+
+=head1 METHODS
+
+
+=head2 new
+
+Usage:
+
+ new(%args) -> [$status_code, $reason, $payload, \%result_meta]
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<aoa>* => I<aoa>
+
+=item * B<column_names>* => I<aos>
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element ($status_code) is an integer containing HTTP-like status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
+
+Return value:  (any)
 
 =head1 HOMEPAGE
 
