@@ -3,13 +3,14 @@ package TableDataRole::Munge::Filter;
 use 5.010001;
 use strict;
 use warnings;
+use Log::ger;
 
 use Role::Tiny;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-09-28'; # DATE
+our $DATE = '2021-09-29'; # DATE
 our $DIST = 'TableDataRoles-Standard'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 with 'TableDataRole::Spec::Basic';
 
@@ -23,6 +24,15 @@ sub new {
     my $filter = delete $args{filter};
     my $filter_hashref = delete $args{filter_hashref};
     ($filter || $filter_hashref) or die "Please supply 'filter' or 'filter_hashref' argument";
+    for ($filter, $filter_hashref) {
+        next unless defined;
+        unless (ref $_ eq 'CODE') {
+            my $code = "package main; sub { no strict; no warnings; $_ }";
+            log_trace "Eval-ing: $code";
+            $_ = eval $code; ## no critic: BuiltinFunctions::ProhibitStringyEval
+            die if $@;
+        }
+    }
     die "Unknown argument(s): ". join(", ", sort keys %args)
         if keys %args;
 
@@ -120,7 +130,7 @@ TableDataRole::Munge::Filter - Role to filter rows from another tabledata
 
 =head1 VERSION
 
-This document describes version 0.012 of TableDataRole::Munge::Filter (from Perl distribution TableDataRoles-Standard), released on 2021-09-28.
+This document describes version 0.013 of TableDataRole::Munge::Filter (from Perl distribution TableDataRoles-Standard), released on 2021-09-29.
 
 =head1 SYNOPSIS
 
